quantizationtools.MeasurewiseQSchema
====================================

.. abjad-lineage:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema

.. autoclass:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.item_class
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.items
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.search_tree
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.target_class
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.target_item_class
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.tempo
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.time_signature
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.use_full_measure
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__call__
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__eq__
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__format__
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__getitem__
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__ne__
      ~abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__repr__

Bases
-----

- :py:class:`quantizationtools.QSchema <abjad.tools.quantizationtools.QSchema.QSchema>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.item_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.items
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.target_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.target_item_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.tempo
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.time_signature
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.use_full_measure
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchema.MeasurewiseQSchema.__repr__
   :noindex:
